<p align="center">
  <img height="180" src="https://s3.us-west-1.amazonaws.com/data.kumo.ai/img/kumo_pink_md.svg" />
</p>

______________________________________________________________________

The Kumo SDK implements a pythonic interface for users to programmatically
interact with the Kumo machine learning platform
([documentation](https://kumo-ai.github.io/kumo-sdk/docs/#)).

## Installation

The Kumo SDK is available for Python 3.9 to Python 3.12. To install, simply run

```
pip install kumoai
```
